summaryrefslogtreecommitdiffstats
path: root/xlators/mgmt/glusterd/src/glusterd.h
diff options
context:
space:
mode:
Diffstat (limited to 'xlators/mgmt/glusterd/src/glusterd.h')
-rw-r--r--xlators/mgmt/glusterd/src/glusterd.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/xlators/mgmt/glusterd/src/glusterd.h b/xlators/mgmt/glusterd/src/glusterd.h
index 34e3e19d32c..587c2e82774 100644
--- a/xlators/mgmt/glusterd/src/glusterd.h
+++ b/xlators/mgmt/glusterd/src/glusterd.h
@@ -210,13 +210,13 @@ struct glusterd_brickinfo {
int32_t snap_status;
/*
* The group is used to identify which bricks are part of the same
* replica set during brick-volfile generation, so that NSR volfiles
* can "cross-connect" the bricks to one another. It is also used by
* AFR to load the arbiter xlator in the appropriate brick in case of
* a replica 3 volume with arbiter enabled.
*/
uint16_t group;
- uuid_t nsr_uuid;
+ uuid_t jbr_uuid;
};
typedef struct glusterd_brickinfo glusterd_brickinfo_t;
@@ -210,13 +210,13 @@ struct glusterd_brickinfo {
/*
* The group is used to identify which bricks are part of the same
- * replica set during brick-volfile generation, so that NSR volfiles
+ * replica set during brick-volfile generation, so that JBR volfiles
* can "cross-connect" the bricks to one another. It is also used by
* AFR to load the arbiter xlator in the appropriate brick in case of